@@ -1063,6 +1063,24 @@ bool BayonneSession::stateRecord(Event *event)
 {
 	char evtmsg[65];
 	char key;
+	time_t now;
+
+	switch(event->id)
+	{
+	case ENTER_STATE:
+		time(&audiotimer);
+		break;
+	case STOP_DISCONNECT:
+	case STOP_SCRIPT:
+	case CALL_DISCONNECT:
+	case CALL_FAILURE:
+		time(&now);
+		if(now - audiotimer > 3)
+			break;
+		if(state.audio.total < 30000)
+			break;
+		remove(state.audio.list[0]);
+	}
 
         if(enterRecord(event))
                 return true;
@@ -1728,6 +1746,7 @@ bool BayonneSession::stateHangup(Event *event)
 	case LINE_WINK:
 	case LINE_DISCONNECT:
 	case STOP_DISCONNECT:
+	case CALL_DISCONNECT:
 	case STOP_SCRIPT:
 	case EXIT_THREAD:
 	case MAKE_IDLE:		// ignore since already going idle
