@@ -560,7 +560,7 @@ BayonneTranslator *BayonneTranslator::loadTranslator(const char *id)
 #ifdef  WIN32
 #ifdef	HAVE_TESTING
         if(!prefix && provision_test)
-#ifdef  NDEBUG
+#ifdef  _DEBUG
                 prefix = "DEBUG";
 #else    
                 prefix = "RELEASE";
@@ -615,7 +615,7 @@ retry:
 		}
 
 		if(server)
-	                errlog("access", "cannot load %s", path);
+	                errlog("access", "cannot load translator %s", path);
                 return NULL;
         }
 
