@@ -954,7 +954,7 @@ sip404:
 				break;
 			}
 			else if(reg)
-				scr = reg->scr;
+				scr = img->getScript(reg->scr->name);
 
 			s = getIdle();
 
