@@ -104,7 +104,7 @@ static Keydata::Define server[] = {
 	{"state", "init"},
 	{"logging", "warn"},
 	{"monitoring", "tcp"},
-	{"binding", "ivrscript1"},
+	{"binding", "default"},
 	{NULL, NULL}};
 
 static Keydata::Define engine[] = {
@@ -566,7 +566,6 @@ retry:
         if(!strnicmp("--", option, 2))
                 ++option;
 	
-#ifdef	HAVE_TESTING
 	if(!strnicmp(option, "-driver=", 8))
 	{
 		keyengine.setValue("driver", option + 8);
@@ -595,6 +594,7 @@ retry:
                 goto retry;
         }  
 
+#ifdef	HAVE_TESTING
         if(!strnicmp(option, "-test=", 6))
         {
 		testConfig(argv0);
@@ -650,6 +650,7 @@ retry:
                 ++argv;
                 goto retry;
         }
+#endif
             
 	if(!stricmp(option, "-check"))
 	{
@@ -658,7 +659,6 @@ retry:
 		++argv;
 		goto retry;
 	}
-#endif
 
 	if(!strnicmp(option, "-vvv", 4))
 	{
@@ -692,7 +692,6 @@ retry:
 		goto retry;
 	}
 
-#ifdef	HAVE_TESTING
 	if(!strnicmp(option, "-voice=", 7))
 	{
 		keyserver.setValue("voice", option + 7);
@@ -715,6 +714,7 @@ retry:
                 goto retry;
         }
 
+#ifdef	HAVE_TESTING
         if(!stricmp(option, "-libexec"))
         {
                 ++argv;
@@ -763,6 +763,7 @@ retry:
                 keyserver.setValue("logging", *(argv++));
                 goto retry;
         }
+#endif
 
         if(!stricmp(option, "-location"))  
         {
@@ -852,7 +853,6 @@ retry:
 		++argv;
                 goto retry;
 	}
-#endif
 
 	if(**argv == '-')
 	{
@@ -896,7 +896,7 @@ skip:
 				else
 					script = NULL;
 
-				runtime.setValue(prefix, *argv);
+				runtime.setValue(*argv, prefix);
 			}
 		}
 		else
